import { useState } from "react";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { Card, CardContent } from "@/components/ui/card";
import { Dialog, DialogContent, DialogDescription, DialogFooter, DialogHeader, DialogTitle } from "@/components/ui/dialog";
import { Copy, Link2, QrCode, CheckCircle, BookmarkPlus } from "lucide-react";
import { supabase } from "@/integrations/supabase/client";
import { useToast } from "@/hooks/use-toast";
import { useNavigate } from "react-router-dom";
import QRCodeJS from "qrcode";

const HeroQuickActions = () => {
  const [url, setUrl] = useState("");
  const [shortUrl, setShortUrl] = useState("");
  const [qrCodeDataUrl, setQrCodeDataUrl] = useState("");
  const [isLoading, setIsLoading] = useState(false);
  const [showSaveDialog, setShowSaveDialog] = useState(false);
  const [createdLink, setCreatedLink] = useState<{id: string, type: string} | null>(null);
  const { toast } = useToast();
  const navigate = useNavigate();

  const generateShortCode = () => {
    return Math.random().toString(36).substring(2, 8);
  };

  const validateUrl = (inputUrl: string) => {
    let validatedUrl = inputUrl.trim();
    if (!validatedUrl.startsWith('http://') && !validatedUrl.startsWith('https://')) {
      validatedUrl = 'https://' + validatedUrl;
    }
    return validatedUrl;
  };

  const generateSessionId = () => {
    return 'session_' + Math.random().toString(36).substring(2, 15);
  };

  const createShortLink = async () => {
    if (!url.trim()) {
      toast({
        title: "URL Required",
        description: "Please enter a URL to shorten",
        variant: "destructive",
      });
      return;
    }

    setIsLoading(true);
    try {
      const validatedUrl = validateUrl(url);
      const shortCode = generateShortCode();
      const sessionId = generateSessionId();

      const { data, error } = await supabase
        .from('temp_links')
        .insert({
          original_url: validatedUrl,
          short_code: shortCode,
          link_type: 'short_link',
          session_id: sessionId
        })
        .select()
        .single();

      if (error) throw error;

      const newShortUrl = `https://l-y.in/s/${shortCode}`;
      setShortUrl(newShortUrl);
      setCreatedLink({ id: data.id, type: 'short_link' });
      setShowSaveDialog(true);

      toast({
        title: "Link shortened successfully!",
        description: "Your short link is ready to use",
      });
    } catch (error: any) {
      console.error('Error creating short link:', error);
      toast({
        title: "Error",
        description: error.message || "Failed to create short link",
        variant: "destructive",
      });
    } finally {
      setIsLoading(false);
    }
  };

  const createQRCode = async () => {
    if (!url.trim()) {
      toast({
        title: "URL Required",
        description: "Please enter a URL to generate QR code",
        variant: "destructive",
      });
      return;
    }

    setIsLoading(true);
    try {
      const validatedUrl = validateUrl(url);
      const qrDataUrl = await QRCodeJS.toDataURL(validatedUrl, {
        width: 200,
        margin: 2,
        color: {
          dark: '#000000',
          light: '#FFFFFF'
        }
      });

      const sessionId = generateSessionId();
      const { data, error } = await supabase
        .from('temp_links')
        .insert({
          original_url: validatedUrl,
          short_code: 'qr_' + Math.random().toString(36).substring(2, 8),
          link_type: 'qr_code',
          session_id: sessionId
        })
        .select()
        .single();

      if (error) throw error;

      setQrCodeDataUrl(qrDataUrl);
      setCreatedLink({ id: data.id, type: 'qr_code' });
      setShowSaveDialog(true);

      toast({
        title: "QR Code generated successfully!",
        description: "Your QR code is ready to download",
      });
    } catch (error: any) {
      console.error('Error generating QR code:', error);
      toast({
        title: "Error",
        description: error.message || "Failed to generate QR code",
        variant: "destructive",
      });
    } finally {
      setIsLoading(false);
    }
  };

  const copyToClipboard = async (text: string) => {
    try {
      await navigator.clipboard.writeText(text);
      toast({
        title: "Copied!",
        description: "Link copied to clipboard",
      });
    } catch (error) {
      toast({
        title: "Copy failed",
        description: "Please copy the link manually",
        variant: "destructive",
      });
    }
  };

  const downloadQRCode = () => {
    if (!qrCodeDataUrl) return;
    
    const link = document.createElement('a');
    link.download = 'qrcode.png';
    link.href = qrCodeDataUrl;
    link.click();
  };

  const handleSaveAndLogin = () => {
    setShowSaveDialog(false);
    // Store the link ID in localStorage to claim it after login
    if (createdLink) {
      localStorage.setItem('linkToClaim', JSON.stringify(createdLink));
    }
    navigate('/login');
  };

  const handleSkip = () => {
    setShowSaveDialog(false);
    setCreatedLink(null);
  };

  return (
    <>
      <Card className="w-full max-w-2xl mx-auto bg-background/95 backdrop-blur border-border shadow-2xl">
        <CardContent className="p-8">
          <div className="text-center mb-4">
            <h3 className="text-lg font-semibold text-foreground mb-1">Quick Tools</h3>
            <p className="text-sm text-muted-foreground">No signup required</p>
          </div>

          <Tabs defaultValue="shortener" className="w-full">
            <TabsList className="grid w-full grid-cols-2">
              <TabsTrigger value="shortener" className="flex items-center gap-2">
                <Link2 className="w-4 h-4" />
                Shorten
              </TabsTrigger>
              <TabsTrigger value="qr" className="flex items-center gap-2">
                <QrCode className="w-4 h-4" />
                QR Code
              </TabsTrigger>
            </TabsList>

            <div className="mt-4">
              <Input
                type="url"
                placeholder="Enter your URL here..."
                value={url}
                onChange={(e) => setUrl(e.target.value)}
                className="mb-3"
                onKeyDown={(e) => {
                  if (e.key === 'Enter') {
                    e.preventDefault();
                    const activeTab = document.querySelector('[data-state="active"]')?.getAttribute('value');
                    if (activeTab === 'shortener') {
                      createShortLink();
                    } else {
                      createQRCode();
                    }
                  }
                }}
              />

              <TabsContent value="shortener" className="mt-0">
                <Button 
                  onClick={createShortLink} 
                  disabled={isLoading || !url.trim()}
                  className="w-full mb-3"
                >
                  {isLoading ? (
                    <div className="flex items-center gap-2">
                      <div className="w-4 h-4 border-2 border-current border-t-transparent rounded-full animate-spin" />
                      Creating...
                    </div>
                  ) : (
                    "Shorten URL"
                  )}
                </Button>

                {shortUrl && (
                  <div className="p-3 bg-muted rounded-md">
                    <div className="flex items-center justify-between gap-2">
                      <span className="text-sm text-foreground truncate font-mono">{shortUrl}</span>
                      <Button
                        variant="ghost"
                        size="sm"
                        onClick={() => copyToClipboard(shortUrl)}
                      >
                        <Copy className="w-4 h-4" />
                      </Button>
                    </div>
                  </div>
                )}
              </TabsContent>

              <TabsContent value="qr" className="mt-0">
                <Button 
                  onClick={createQRCode} 
                  disabled={isLoading || !url.trim()}
                  className="w-full mb-3"
                >
                  {isLoading ? (
                    <div className="flex items-center gap-2">
                      <div className="w-4 h-4 border-2 border-current border-t-transparent rounded-full animate-spin" />
                      Generating...
                    </div>
                  ) : (
                    "Generate QR Code"
                  )}
                </Button>

                {qrCodeDataUrl && (
                  <div className="text-center">
                    <img 
                      src={qrCodeDataUrl} 
                      alt="Generated QR Code" 
                      className="mx-auto mb-3 rounded-md"
                      width={200}
                      height={200}
                      loading="lazy"
                    />
                    <Button
                      variant="outline"
                      size="sm"
                      onClick={downloadQRCode}
                      className="w-full"
                    >
                      Download QR Code
                    </Button>
                  </div>
                )}
              </TabsContent>
            </div>
          </Tabs>
        </CardContent>
      </Card>

      <Dialog open={showSaveDialog} onOpenChange={setShowSaveDialog}>
        <DialogContent>
          <DialogHeader>
            <DialogTitle className="flex items-center gap-2">
              <BookmarkPlus className="w-5 h-5" />
              Save Your Link
            </DialogTitle>
            <DialogDescription>
              Want to view analytics and manage your links? Save this link to your account!
            </DialogDescription>
          </DialogHeader>
          <DialogFooter className="gap-2">
            <Button variant="outline" onClick={handleSkip}>
              Skip for now
            </Button>
            <Button onClick={handleSaveAndLogin}>
              Save & Login
            </Button>
          </DialogFooter>
        </DialogContent>
      </Dialog>
    </>
  );
};

export default HeroQuickActions;
